# SOFI_SET_PREFIX(PREFIX)
#---------------------------
AC_DEFUN([SOFI_SET_PREFIX],
[
    unset CDPATH
    # make $PIPE_HOME the default for the installation
    AC_PREFIX_DEFAULT($1)

    if test "x$prefix" = "xNONE"; then
        prefix=$ac_default_prefix
        ac_configure_args="$ac_configure_args --prefix $prefix"
    fi

    if test "x$exec_prefix" = "xNONE"; then
        exec_prefix=$prefix
    fi

])


# SOFI_SET_VERSION_INFO(VERSION, [CURRENT], [REVISION], [AGE])
#----------------------------------------------------------------
# Setup various version information, especially the libtool versioning
AC_DEFUN([SOFI_SET_VERSION_INFO],
[
    sofi_version=`echo "$1" | sed -e 's/[[a-z,A-Z]].*$//'`

    sofi_major_version=`echo "$sofi_version" | \
        sed 's/\([[0-9]]*\).\(.*\)/\1/'`
    sofi_minor_version=`echo "$sofi_version" | \
        sed 's/\([[0-9]]*\).\([[0-9]]*\)\(.*\)/\2/'`
    sofi_micro_version=`echo "$sofi_version" | \
        sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\3/'`

    if test -z "$sofi_major_version"; then sofi_major_version=0
    fi

    if test -z "$sofi_minor_version"; then sofi_minor_version=0
    fi

    if test -z "$sofi_micro_version"; then sofi_micro_version=0
    fi

    SOFI_VERSION="$sofi_version"
    SOFI_MAJOR_VERSION=$sofi_major_version
    SOFI_MINOR_VERSION=$sofi_minor_version
    SOFI_MICRO_VERSION=$sofi_micro_version

    if test -z "$4"; then SOFI_INTERFACE_AGE=0
    else SOFI_INTERFACE_AGE="$4"
    fi

    SOFI_BINARY_AGE=`expr 100 '*' $SOFI_MINOR_VERSION + $SOFI_MICRO_VERSION`
    SOFI_BINARY_VERSION=`expr 10000 '*' $SOFI_MAJOR_VERSION + \
                          $SOFI_BINARY_AGE`

    AC_SUBST(SOFI_VERSION)
    AC_SUBST(SOFI_MAJOR_VERSION)
    AC_SUBST(SOFI_MINOR_VERSION)
    AC_SUBST(SOFI_MICRO_VERSION)
    AC_SUBST(SOFI_INTERFACE_AGE)
    AC_SUBST(SOFI_BINARY_VERSION)
    AC_SUBST(SOFI_BINARY_AGE)

    AC_DEFINE_UNQUOTED(SOFI_MAJOR_VERSION, $SOFI_MAJOR_VERSION,
                       [SOFI major version number])
    AC_DEFINE_UNQUOTED(SOFI_MINOR_VERSION, $SOFI_MINOR_VERSION,
                       [SOFI minor version number])
    AC_DEFINE_UNQUOTED(SOFI_MICRO_VERSION, $SOFI_MICRO_VERSION,
                       [SOFI micro version number])
    AC_DEFINE_UNQUOTED(SOFI_INTERFACE_AGE, $SOFI_INTERFACE_AGE,
                       [SOFI interface age])
    AC_DEFINE_UNQUOTED(SOFI_BINARY_VERSION, $SOFI_BINARY_VERSION,
                       [SOFI binary version number])
    AC_DEFINE_UNQUOTED(SOFI_BINARY_AGE, $SOFI_BINARY_AGE,
                       [SOFI binary age])

    ESO_SET_LIBRARY_VERSION([$2], [$3], [$4])
])


# SOFI_SET_PATHS
#------------------
# Define auxiliary directories of the installed directory tree.
AC_DEFUN([SOFI_SET_PATHS],
[

    if test -z "$plugindir"; then
        plugindir='${libdir}/esopipes-plugins/${PACKAGE}-${VERSION}'
    fi

    if test -z "$pipedocsdir"; then
        pipedocsdir='${datadir}/doc/esopipes/${PACKAGE}-${VERSION}'
    fi
    htmldir='${pipedocsdir}/html'

    if test -z "$configdir"; then
       configdir='${datadir}/${PACKAGE}/config'
    fi

    if test -z "$privatelibdir"; then
       privatelibdir='${libdir}/${PACKAGE}-${VERSION}'
    fi

    AC_SUBST(plugindir)
    AC_SUBST(htmldir)
    AC_SUBST(configdir)
    AC_SUBST(privatelibdir)
    AC_SUBST(pipedocsdir)


    # Define a preprocesor symbol for the plugin search paths

    AC_DEFINE_UNQUOTED(SOFI_PLUGIN_DIR, "esopipes-plugins",
                       [Plugin directory tree prefix])

    eval plugin_dir="$plugindir"
    plugin_path=`eval echo $plugin_dir | \
                sed -e "s/\/${PACKAGE}-${VERSION}.*$//"`

    AC_DEFINE_UNQUOTED(SOFI_PLUGIN_PATH, "$plugin_path",
                       [Absolute path to the plugin directory tree])

])


# SOFI_CREATE_SYMBOLS
#-----------------------
# Define include and library related makefile symbols
AC_DEFUN([SOFI_CREATE_SYMBOLS],
[

    # Symbols for package include file and library search paths

    SOFI_INCLUDES='-I$(top_srcdir)/sofi -I$(top_srcdir)/irplib'
    SOFI_LDFLAGS='-L$(top_builddir)/sofi'

    all_includes='$(SOFI_INCLUDES) $(CPL_INCLUDES) $(EXTRA_INCLUDES)'
    all_ldflags='$(SOFI_LDFLAGS) $(CPL_LDFLAGS) $(EXTRA_LDFLAGS)'

    # Library aliases

    LIBSOFI='$(top_builddir)/sofi/libsofi.la'
    LIBIRPLIB='$(top_builddir)/irplib/libirplib.la'

    # Substitute the defined symbols

    AC_SUBST(SOFI_INCLUDES)
    AC_SUBST(SOFI_LDFLAGS)

    AC_SUBST(LIBSOFI)
    AC_SUBST(LIBIRPLIB)

    # Check for CPL and user defined libraries
    AC_REQUIRE([CPL_CHECK_LIBS])
    AC_REQUIRE([ESO_CHECK_EXTRA_LIBS])

    all_includes='$(SOFI_INCLUDES) $(CPL_INCLUDES) $(EXTRA_INCLUDES)'
    all_ldflags='$(SOFI_LDFLAGS) $(CPL_LDFLAGS) $(EXTRA_LDFLAGS)'

    AC_SUBST(all_includes)
    AC_SUBST(all_ldflags)
])
