/* $Id: recipe_main.c,v 1.7 2011-07-11 12:43:28 llundin Exp $
 *
 * This file is part of the VISIR Pipeline
 * Copyright (C) 2002,2003 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02111-1307  USA
 */

/*
 * $Author: llundin $
 * $Date: 2011-07-11 12:43:28 $
 * $Revision: 1.7 $
 * $Name: not supported by cvs2svn $
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

/*-----------------------------------------------------------------------------
                                Includes
 -----------------------------------------------------------------------------*/

#include <cpl.h>

#include <irplib_plugin.h>


/*----------------------------------------------------------------------------*/
/**
 * @defgroup recipe_main   General plugin tests
 */
/*----------------------------------------------------------------------------*/

/**@{*/

/*-----------------------------------------------------------------------------
                            Function definitions
 -----------------------------------------------------------------------------*/


/*----------------------------------------------------------------------------*/
/**
  @brief    Find a plugin and submit it to some tests
  @return   0 iff succesful

 */
/*----------------------------------------------------------------------------*/
int main(void)
{

    const char * tags[] = {
        "CALPRO_OH_CATALOG",
        "CALPRO_OH_CATALOG",
        "CALPRO_OH_CATALOG",
        "CALPRO_OH_CATALOG",
        "CALPRO_OH_CATALOG",
        "CALPRO_XE_CATALOG",
        "CALPRO_XE_CATALOG",
        "CALPRO_XE_CATALOG",
        "CALPRO_XE_CATALOG",
        "CALPRO_XE_CATALOG",
        "CALPRO_NE_CATALOG",
        "CALPRO_NE_CATALOG",
        "CALPRO_NE_CATALOG",
        "CALPRO_NE_CATALOG",
        "CALPRO_NE_CATALOG",
        "STDSTARS_CATS",
        "STDSTARS_CATS",
        "STDSTARS_CATS",
        "STDSTARS_CATS",
        "STDSTARS_CATS",
        "MASTER_IMG_FLAT",
        "MASTER_IMG_FLAT",
        "MASTER_IMG_FLAT",
        "MASTER_IMG_FLAT",
        "MASTER_IMG_FLAT",
        "MASTER_DARK",
        "MASTER_DARK",
        "MASTER_DARK",
        "MASTER_DARK",
        "MASTER_DARK",
        "MASTER_SP_FLAT",
        "MASTER_SP_FLAT",
        "MASTER_SP_FLAT",
        "MASTER_SP_FLAT",
        "MASTER_SP_FLAT",
        "ARC_COEF",
        "ARC_COEF",
        "ARC_COEF",
        "ARC_COEF",
        "ARC_COEF",
        "DETLIN_A",
        "DETLIN_A",
        "DETLIN_A",
        "DETLIN_A",
        "DETLIN_A",
        "DETLIN_B",
        "DETLIN_B",
        "DETLIN_B",
        "DETLIN_B",
        "DETLIN_B",
        "DETLIN_C",
        "DETLIN_C",
        "DETLIN_C",
        "DETLIN_C",
        "DETLIN_C",
        "IM_ZPOINT",
        "IM_ZPOINT",
        "IM_ZPOINT",
        "IM_ZPOINT",
        "IM_ZPOINT",
        "IM_FLAT",
        "IM_FLAT",
        "IM_FLAT",
        "IM_FLAT",
        "IM_FLAT",
        "IM_DARK",
        "IM_DARK",
        "IM_DARK",
        "IM_DARK",
        "IM_DARK",
        "IM_JITTEROBJ",
        "IM_JITTEROBJ",
        "IM_JITTEROBJ",
        "IM_JITTEROBJ",
        "IM_JITTEROBJ",
        "IM_JITTERSKY",
        "IM_JITTERSKY",
        "IM_JITTERSKY",
        "IM_JITTERSKY",
        "IM_JITTERSKY",
        "IM_ILLUM",
        "IM_ILLUM",
        "IM_ILLUM",
        "IM_ILLUM",
        "IM_ILLUM",
        "LINEAR_LAMP",
        "LINEAR_LAMP",
        "LINEAR_LAMP",
        "LINEAR_LAMP",
        "LINEAR_LAMP",
        "LINEAR_DARK",
        "LINEAR_DARK",
        "LINEAR_DARK",
        "LINEAR_DARK",
        "LINEAR_DARK",
        "SP_FLAT", /* FITS read is attempted with four frames */
        "SP_FLAT",
        "SP_FLAT",
        "SP_FLAT",
        "SP_ARC",
        "SP_ARC",
        "SP_ARC",
        "SP_ARC",
        "SP_ARC",
        "SP_NODDINGOBJ",
        "SP_NODDINGOBJ",
        "SP_NODDINGOBJ",
        "SP_NODDINGOBJ",
        "SP_NODDINGOBJ",
        "SP_NODDINGSKY",
        "SP_NODDINGSKY",
        "SP_NODDINGSKY",
        "SP_NODDINGSKY",
        "SP_NODDINGSKY",
        "STDSTAR_CAT",
        "STDSTAR_CAT",
        "STDSTAR_CAT",
        "STDSTAR_CAT",
        "STDSTAR_CAT",
        "CATALOG",
        "CATALOG",
        "CATALOG",
        "CATALOG",
        "CATALOG",
    };

    cpl_pluginlist * pluginlist;
    const size_t ntags = sizeof(tags) / sizeof(char*);

    cpl_test_init(PACKAGE_BUGREPORT, CPL_MSG_WARNING);

    pluginlist = cpl_pluginlist_new();

    cpl_test_zero(cpl_plugin_get_info(pluginlist));

    /* FIXME: Remove plugins when they have been fixed */
    if (cpl_pluginlist_find(pluginlist, "sofi_img_dark") ||
        cpl_pluginlist_find(pluginlist, "sofi_img_detlin") ||
        cpl_pluginlist_find(pluginlist, "sofi_img_domeflat") ||
        cpl_pluginlist_find(pluginlist, "sofi_img_jitter") ||
        cpl_pluginlist_find(pluginlist, "sofi_util_stdstars")) {

        cpl_msg_warning(cpl_func, "Skipping test of %d plugin(s):",
                        cpl_pluginlist_get_size(pluginlist));
        if (cpl_msg_get_level() <= CPL_MSG_INFO)
            cpl_pluginlist_dump(pluginlist, stdout);
    } else {
        cpl_test_zero(irplib_plugin_test(pluginlist, ntags, tags));
    }

    cpl_pluginlist_delete(pluginlist);

    return cpl_test_end(0);
}

/**@}*/
